<?php
/*
* Plugin Name: Sleeker Admin Color Schemes
* Plugin URI: https://sleeker.org/admin-color-schemes/
* Description: Adds new admin color schemes with 3D effect to the WordPress admin panel.
* Version: 1.3
* Author: Sleeker
* Author URI: https://sleeker.org/
* Tested up to: 6.7.1
* Requires PHP: 7.4
* License: GPL v2 or later
* License URI: https://www.gnu.org/licenses/gpl-2.0.html
* Text Domain: sleeker-admin-color-schemes
*/

// Prevent direct access to the file
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Hook to register the custom color schemes
add_action('admin_init', 'sleeker_register_admin_color_schemes');

function sleeker_register_admin_color_schemes() {
    // Orange3D color scheme
    wp_admin_css_color(
        'orange3d', 
        __('Orange 3D', 'sleeker-admin-color-schemes'), 
        plugins_url('css/orange3d.min.css', __FILE__), 
        array('#1f1f1f', '#b04600', '#ff6600')
    );

    // Ochre3D color scheme
    wp_admin_css_color(
        'ochre3d', 
        __('Ochre 3D', 'sleeker-admin-color-schemes'), 
        plugins_url('css/ochre3d.min.css', __FILE__), 
        array('#1f1f1f', '#a26100', '#ffaa00')
    );

    // Green3D color scheme
    wp_admin_css_color(
        'green3d', 
        __('Green 3D', 'sleeker-admin-color-schemes'), 
        plugins_url('css/green3d.min.css', __FILE__), 
        array('#1f1f1f', '#005a00', '#009900')
    );

    // Magenta3D color scheme
    wp_admin_css_color(
        'magenta3d', 
        __('Magenta 3D', 'sleeker-admin-color-schemes'), 
        plugins_url('css/magenta3d.min.css', __FILE__), 
        array('#1f1f1f', '#b100b1', '#f600f6')
    );

    // Violet3D color scheme
    wp_admin_css_color(
        'violet3d', 
        __('Violet 3D', 'sleeker-admin-color-schemes'), 
        plugins_url('css/violet3d.min.css', __FILE__), 
        array('#1f1f1f', '#5400a9', '#972fff')
    );
}

// Enqueue styles when any custom color scheme is active
add_action('admin_enqueue_scripts', 'sleeker_enqueue_custom_color_scheme_styles');

function sleeker_enqueue_custom_color_scheme_styles() {
    $user_color = get_user_option('admin_color');
    $allowed_schemes = array('orange3d', 'ochre3d', 'green3d', 'magenta3d', 'violet3d');

    if (in_array($user_color, $allowed_schemes)) {
        $css_file = plugin_dir_path(__FILE__) . 'css/' . $user_color . '.css';
        $css_url = plugins_url('css/' . $user_color . '.css', __FILE__);
        
        // Use file modification time for versioning to ensure cache busting when the file changes
        $version = file_exists($css_file) ? filemtime($css_file) : '1.3'; // Fallback to plugin version if file doesn't exist
        
        wp_enqueue_style(
            $user_color . '-admin-color-scheme', 
            $css_url,
            array(),         // Dependencies (empty in this case)
            $version         // Version parameter added here
        );
    }
}

// Plugin activation hook to ensure it's properly registered
register_activation_hook(__FILE__, function() {
    if (!current_user_can('activate_plugins')) {
        return;
    }
    // Perform activation tasks if necessary
});

// Plugin deactivation hook
register_deactivation_hook(__FILE__, function() {
    if (!current_user_can('activate_plugins')) {
        return;
    }
    // Perform deactivation tasks if necessary
});
